==> cdf33_0-dist-cdf.tar.gz: cdf33_0-dist/src/include/cdfvalidate.h <==
/******************************************************************************
*
*  NSSDC/CDF					Header file for cdfvalidate.
*
*  Version 1.0, 20-Aug-08, Perot System.
*
*  Modification history:
*
*   V1.0  20-Aug-08, M Liu 	Original version.
*
******************************************************************************/

#if !defined(CDFValidateh_INCLUDEd__)
#define CDFValidateh_INCLUDEd__

/******************************************************************************
* Include files.
******************************************************************************/

#include "cdflib.h"
#include "cdflib64.h"
#include "cdftools.h"

/******************************************************************************
* QOP constants.
******************************************************************************/

#define DEBUGqual		0
#define ABOUTqual		1
#define VALIDATEqual            2
#define NOVALIDATEqual          3

/******************************************************************************
* Global variables.
******************************************************************************/
#if defined(CDFVALIDATE)
Logical useValidate = DEFAULTvalidate;
#else
extern Logical useValidate;
#endif

/******************************************************************************
* Function Prototypes.
******************************************************************************/

Logical ValidateCDFs PROTOARGs((int argC, char *argV[]));

/*****************************************************************************/

#endif

==> cdf34_1-dist-cdf.tar.gz: cdf34_1-dist/src/include/cdfvalidate.h <==
/******************************************************************************
*
*  NSSDC/CDF					Header file for cdfvalidate.
*
*  Version 1.0, 20-Aug-08, Perot System.
*
*  Modification history:
*
*   V1.0  20-Aug-08, M Liu 	Original version.
*
******************************************************************************/

#if !defined(CDFValidateh_INCLUDEd__)
#define CDFValidateh_INCLUDEd__

/******************************************************************************
* Include files.
******************************************************************************/

#include "cdflib.h"
#include "cdflib64.h"
#include "cdftools.h"

/******************************************************************************
* QOP constants.
******************************************************************************/

#define NODEBUGqual		0
#define DEBUGqual		1
#define ABOUTqual		2
#define VALIDATEqual            3
#define NOVALIDATEqual          4

/******************************************************************************
* Global variables.
******************************************************************************/
#if defined(CDFVALIDATE)
Logical useValidate = DEFAULTvalidateValidate;
Logical debug = DEFAULTdebugValidate;
#else
extern Logical useValidate;
extern Logical debug;
#endif

/******************************************************************************
* Function Prototypes.
******************************************************************************/

Logical ValidateCDFs PROTOARGs((int argC, char *argV[]));

/*****************************************************************************/

#endif
